//
//  CompressModuleBridge.swift
//  RNVideoCompression
//
//  Created by Abdul Azeem on 16/10/20.
//  Copyright © 2020 Facebook. All rights reserved.
//

import AVFoundation

@objc(CompressModule)
class CompressModule: NSObject {

  @objc
  func compressVideo(_ inputPath: String , callback: @escaping RCTResponseSenderBlock) {
    let audioSettings = [
        AVFormatIDKey: kAudioFormatMPEG4AAC,
        AVNumberOfChannelsKey: 2,
        AVSampleRateKey: 44100,
        AVEncoderBitRateKey: 128000
    ]
    let asset = AVAsset(url: URL(string: inputPath)!)
    let outputPath = NSURL.fileURL(withPath: NSTemporaryDirectory() + NSUUID().uuidString + ".mp4")
    VAVideoCompressor.exportAsynchronously(
        with: asset,
        outputFileType: AVFileType.mp4,
        outputURL: outputPath,
        videoSettings: VAVideoCompressor.videoSettingsForPreset(.medium, size: asset.videoSize()),
        audioSettings: audioSettings,
        completion: { error in
            if let error = error {
              print(error)
              callback(["error"])
            } else {
              print("success: \(outputPath)")
              callback([outputPath.absoluteString])
            }
    })
  }
    
  @objc
  func constantsToExport() -> [String: Any]! {
    return ["someKey": "someValue"]
  }
    
}

